package com.example.asyncapi.config;

import com.asyncapi.v2.binding.kafka.KafkaOperationBinding;
import com.asyncapi.v2.model.info.Info;
import com.asyncapi.v2.model.server.Server;
import com.google.common.collect.ImmutableMap;
import io.github.stavshamir.springwolf.asyncapi.types.ProducerData;
import io.github.stavshamir.springwolf.configuration.AsyncApiDocket;
import io.github.stavshamir.springwolf.configuration.EnableAsyncApi;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.List;

@Configuration
@EnableAsyncApi
public class AsyncApiConfig {

    @Value("${springwolf.paths.docs}")
    private String springFoxApiUrl;

    @Value("${application.async-api.base-package}")
    private String basePackage;


    @Bean
    public AsyncApiDocket asyncApiDocket() throws ClassNotFoundException {
        Info info = Info.builder()
                .version("0.0.1")
                .title("Async-api-test")
                .build();

        Server kafkaServer = Server.builder()
                .protocol("kafka")
                .url("localhost:9092")
                .build();

        ProducerData producer = ProducerData.builder()
                .channelName("ACCOUNT")
                .payloadType(com.example.asyncapi.model.ClassA.class)
                .binding(ImmutableMap.of("kafka", new KafkaOperationBinding()))
                .build();

        ProducerData producer1 = ProducerData.builder()
                .channelName("ACCOUNT")
                .payloadType(com.example.asyncapi.model.ClassB.class)
                .binding(ImmutableMap.of("kafka", new KafkaOperationBinding()))
                .build();

        return AsyncApiDocket.builder()
                .basePackage(this.basePackage)
                .info(info)
                .producers(List.of(producer, producer1))
                .server("kafka", kafkaServer)
                .build();
    }
}
